package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````0!X```````!``````````&"U````
M`````````$``.``(`$``'0`<``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````'R>````````?)X`````````
M`"````````$````&````N*T```````"XK2```````+BM(```````J`0`````
M```0!0``````````(````````@````8```#@K0```````."M(```````X*T@
M``````#``0```````,`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````W)8```````#<E@```````-R6````````%`$````````4`0````````0`
M````````4N5T9`0```"XK0```````+BM(```````N*T@``````!(`@``````
M`$@"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0``,"OTC4$````!`````,```!085@```````````!A
M````8P``````````````,````!L```````````````<```!-`````@``````
M``!!`````````#T````0````1P`````````R````!0```!8```!&````40``
M``L```!*````"0```!P`````````%0```%L````_````3``````````O````
M80```&(````:````1````$L```!#````6@```!X`````````"@```#L```!"
M````,0```"$```!8`````````#H````S`````````"P````W````60```"0`
M```G````7P```%````!=`````````%8`````````50```"D````.````````
M````````````3P```"H``````````````%X````U`````````#P`````````
M-@```&``````````4@```!D````4`````````%,`````````````````````
M````0`````````!7````+@```#0`````````7```````````````````````
M``````````````$`````````````````````````````````````````````
M```````````````````````$``````````P`````````````````````````
M````````````````````````````````$0``````````````````````````
M````$P```",```````````````,````````````````````H``````````\`
M````````)0`````````K``````````````````````````@````8````````
M```````````````````````F```````````````7````(@``````````````
M/@```!T````2``````````````````````````````````````````8`````
M````10```$X```!)````````````````````(```````````````.````$@`
M```Y````5``````````-````'P```"T`````````````````````````````
M``````!@`P``$@`,`$Y4````````!0(```````#``0``$@``````````````
M``````````"]````$0````````````````````````"R`0``$@``````````
M``````````````!G````$@`````````````````````````,````$@``````
M``````````````````!S`0``$@````````````````````````!E`P``$@`,
M`&DO````````(0````````!G`@``$@`````````````````````````D`@``
M$@````````````````````````"(````$``-`&!6```````````````````3
M`@``$@````````````````````````!_`0``$@``````````````````````
M``#(`0``(`````````````````````````!_`@``$@``````````````````
M```````K`@``$@````````````````````````"T`@``$@``````````````
M```````````$`P``$0`7`/"Q(```````"`````````#C`@``$@``````````
M``````````````#@`0``$@````````````````````````!M````$@``````
M``````````````````"``P``$@`,`&,I`````````P````````".````$@``
M```````````````````````H`0``$@`````````````````````````4````
M$@````````````````````````!3`@``(``````````````````````````X
M````$@`````````````````````````/`P``$0`8`("R(```````"```````
M``!`````$@`````````````````````````(`@``$@``````````````````
M``````"1`P``$@`,`(HO````````N@````````#V````$@``````````````
M``````````"C`P``$@`,`$0P````````G@8````````=!```$``)`%`:````
M``````````````#R`@``$@````````````````````````"%`@``$@``````
M```````````````````<`P``$@`````````````````````````Y`@``$@``
M``````````````````````"P`P``$@`,`.XH````````-0````````#8````
M%@````````````````````````#K````$@````````````````````````!!
M`0``$@````````````````````````"X`P``$@`,`$`>````````````````
M```Q````$@````````````````````````#*````$@``````````````````
M``````#``P``$@`,`#PM````````5`````````#.`P``$@`,`.(V````````
M.@(```````#D`P``$@`,`+Q/````````MP$```````#O`P``$0`7`%BR(```
M````"`````````">````$@````````````````````````"Y`P``$@`,`$`>
M``````````````````"O`@``$0````````````````````````#_````$0`8
M`,"R(```````"`````````#Y`P``$@`,`&4K````````(``````````'`0``
M$@`````````````````````````O`0``$0````````````````````````!D
M`0``$@`````````````````````````<````(@``````````````````````
M``#R`0``(``````````````````````````I`P``$@``````````````````
M```````X`P``$@`````````````````````````Z`@``$@``````````````
M``````````!V`@``$@`````````````````````````&!```$``8`&"R(```
M```````````````<`0``$@````````````````````````!?`0``$@``````
M``````````````````!8````$@`````````````````````````2!```$@`,
M`)`M````````M0`````````K````$@````````````````````````!(````
M$@`````````````````````````:!```$@`,`&A/````````5`````````!"
M`@``$@`````````````````````````C!```$@`,`(4K````````.```````
M``#L`0``$@`````````````````````````O!```$@`,`+TK````````?P$`
M``````"@`@``$@`````````````````````````V`P``$@``````````````
M``````````!1`0``$@````````````````````````"#````$@``````````
M```````````````R`@``$@`````````````````````````\!```$``7`&"R
M(`````````````````!#!```$@`,`&8I````````_P$```````"?`0``$@``
M``````````````````````!0!```$@`,`'-1````````VP(```````!T````
M$@`````````````````````````]`P``$@````````````````````````"4
M`0``$@````````````````````````!(`P``$@``````````````````````
M``!/`P``$@````````````````````````"*`@``$@``````````````````
M``````!;`P``$``8`,BR(`````````````````"7````$@``````````````
M``````````!^````$@````````````````````````"9`@``$@``````````
M``````````````"L````$@````````````````````````!:!```$@`,`!PY
M````````3@````````"2`@``$@`````````````````````````0`0``$@``
M````````````````````````;&EB<&5R;"YS;P!R96%L;&]C`&UE;6UO=F4`
M7U]C>&%?9FEN86QI>F4`<FUD:7(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B
M;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?
M;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``;65M8W!Y`'!E<FQ?
M9&5S=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S
M=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I
M<@!E;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I
M;G1F7V-H:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?;F5W6%,`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<WES7W1E<FT`7U]E<G)N;P!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!097)L7VUG7W-E=`!M:V1I<@!?7W)E9VES=&5R7V9R86UE7VEN9F\`<&5R
M;%]P87)S90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR
M`'9F<')I;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E
M<P!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P<FEN=&8`
M9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M<`!L:6)M
M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H<F5A9%]A
M=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN
M9W,`7U]G971P=W5I9#4P`%]?<W1P8W!Y7V-H:P!A=&5X:70`7VQI8F-?:6YI
M=`!S=')T;VL`7U]R96%D9&ER,S``7V5N9`!M86EN`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`7U]S=&%R=`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P
M87)?8F%S96YA;64`7U]B<W-?<W1A<G0`<&%R7V1I90!S:&%?:6YI=`!P87)?
M9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?
M9FEN86P`<&%R7V-L96%N=7``+W5S<B]P:V<O;&EB+W!E<FPU+S4N,S@N,"]X
M.#9?-C0M;F5T8G-D+71H<F5A9"UM=6QT:2]#3U)%.B]U<W(O<&MG+VQI8@``
M``"PKR````````@`````````X*T@``````#PL2````````@`````````B+(@
M``````#XL2````````@`````````^+$@``````!8LB````````@`````````
M6%D```````"@KR````````8````#``````````````"HKR````````8````.
M``````````````"XKR````````8````:``````````````#`KR```````!(`
M```H``````````````#(KR````````8````T``````````````#0KR``````
M``8````X``````````````#8KR````````8````Z``````````````#@KR``
M``````8````[``````````````#HKR````````8```!&``````````````#P
MKR````````8```!(``````````````#XKR````````8```!3````````````
M```8L"````````<````"```````````````@L"````````<````$````````
M```````HL"````````<````%```````````````PL"````````<````&````
M```````````XL"````````<````'``````````````!`L"````````<````)
M``````````````!(L"````````<````*``````````````!0L"````````<`
M```,``````````````!8L"````````<````-``````````````!@L"``````
M``<````/``````````````!HL"````````<````0``````````````!PL"``
M``````<````1``````````````!XL"````````<````3``````````````"`
ML"````````<````4``````````````"(L"````````<````5````````````
M``"0L"````````<````7``````````````"8L"````````<````8````````
M``````"@L"````````<````9``````````````"HL"````````<````;````
M``````````"PL"````````<````=``````````````"XL"````````<````>
M``````````````#`L"````````<````@``````````````#(L"````````<`
M```C``````````````#0L"````````<````D``````````````#8L"``````
M``<````E``````````````#@L"````````<````F``````````````#HL"``
M``````<````I``````````````#PL"````````<````J``````````````#X
ML"````````<````L````````````````L2````````<````M````````````
M```(L2````````<````R```````````````0L2````````<````W````````
M```````8L2````````<````Y```````````````@L2````````<````\````
M```````````HL2````````<````]```````````````PL2````````<````^
M```````````````XL2````````<````_``````````````!`L2````````<`
M``!!``````````````!(L2````````<```!"``````````````!0L2``````
M``<```!#``````````````!8L2````````<```!%``````````````!@L2``
M``````<```!*``````````````!HL2````````<```!,``````````````!P
ML2````````<```!-``````````````!XL2````````<```!.````````````
M``"`L2````````<```!/``````````````"(L2````````<```!0````````
M``````"0L2````````<```!5``````````````"8L2````````<```!6````
M``````````"@L2````````<```!7``````````````"HL2````````<```!8
M``````````````"PL2````````<```!9``````````````"XL2````````<`
M``!:``````````````#`L2````````<```!<``````````````#(L2``````
M``<```!=``````````````#0L2````````<```!>``````````````#8L2``
M``````<```!?``````````````#@L2````````<```!A``````````````#H
ML2````````<```!B`````````````````````````$B#[`CH4@<``$B#Q`C#
M``#_-:*5(`#_):25(``/'T``_R6BE2``:`````#IX/____\EFI4@`&@!````
MZ=#_____)9*5(`!H`@```.G`_____R6*E2``:`,```#IL/____\E@I4@`&@$
M````Z:#_____)7J5(`!H!0```.F0_____R5RE2``:`8```#I@/____\E:I4@
M`&@'````Z7#_____)6*5(`!H"````.E@_____R5:E2``:`D```#I4/____\E
M4I4@`&@*````Z4#_____)4J5(`!H"P```.DP_____R5"E2``:`P```#I(/__
M__\E.I4@`&@-````Z1#_____)3*5(`!H#@```.D`_____R4JE2``:`\```#I
M\/[___\E(I4@`&@0````Z>#^____)1J5(`!H$0```.G0_O___R42E2``:!(`
M``#IP/[___\E"I4@`&@3````Z;#^____)0*5(`!H%````.F@_O___R7ZE"``
M:!4```#ID/[___\E\I0@`&@6````Z8#^____)>J4(`!H%P```.EP_O___R7B
ME"``:!@```#I8/[___\EVI0@`&@9````Z5#^____)=*4(`!H&@```.E`_O__
M_R7*E"``:!L```#I,/[___\EPI0@`&@<````Z2#^____);J4(`!H'0```.D0
M_O___R6RE"``:!X```#I`/[___\EJI0@`&@?````Z?#]____):*4(`!H(```
M`.G@_?___R6:E"``:"$```#IT/W___\EDI0@`&@B````Z<#]____)8J4(`!H
M(P```.FP_?___R6"E"``:"0```#IH/W___\E>I0@`&@E````Z9#]____)7*4
M(`!H)@```.F`_?___R5JE"``:"<```#I</W___\E8I0@`&@H````Z6#]____
M)5J4(`!H*0```.E0_?___R52E"``:"H```#I0/W___\E2I0@`&@K````Z3#]
M____)4*4(`!H+````.D@_?___R4ZE"``:"T```#I$/W___\E,I0@`&@N````
MZ0#]____)2J4(`!H+P```.GP_/___R4BE"``:#````#IX/S___\E&I0@`&@Q
M````Z=#\____)1*4(`!H,@```.G`_/___R4*E"``:#,```#IL/S___\E`I0@
M`&@T````Z:#\____)?J3(`!H-0```.F0_/___R7RDR``:#8```#I@/S___\E
MZI,@`&@W````Z7#\____)>*3(`!H.````.E@_/___R7:DR``:#D```#I4/S_
M__\ETI,@`&@Z````Z4#\____)8*1(`!FD/\EBI$@`&:0_R6BD2``9I#_):*1
M(`!FD$B#Y/!(@^P(2(G72(G>Z<(!``!F+@\?A```````#Q\`55-(@^P(2(T=
M2X\@`$B-!42/(`!(.<-S&TB-4P%(*=!(P>@#2(ULPPC_$TB#PPA(.>MU]4B#
MQ`A;7<-!5%532(T=HOO__TR-)9O[__],.>-S&8-[""5U&$B+*_]3$$B)10!(
M@\,83#GC<N=;74%<P^B[^___2&/22&/V2(U$,@)(C13'BP*%P`^$Y````+[_
M____,<GK'(/X!P^$Q@```(/X`W4$2(M*"$B#PA"+`H7`=!.#^`5UWP^W<@A(
M@\(0BP*%P'7M2(7)#X2C````9H/^_P^$F0````^WQDAKP#A(`<A(.<@/AH8`
M``"^_____S'_ZQ6#^@9U!TB)SD@K<1!(@\$X2#G(=A.+$8/Z`G7D2(G/2(/!
M.$@YR'?M2(7_=%"X_____T@YQG1&2(M/$$@!\4B+$4B%TG0W,?\QP.L62(/Z
M"'4$2(MY"$B#P1!(BQ%(A=)T'$B#^@=UY$B+00A(`?#KY4B#>@@`#X0X____
MP\-(C0PX2#G!9@\?1```=Q'K[DB#^B5U(DB#P!A(.<%VWXM0"$B#^@AUZ$B+
M$$B+>!!(`?=(B3PRZ]Y(@^P(Z'OZ__]!54%455-(@^P(2(G[2(GUBU88BW8(
M2(M]`.BA_O__2(T%19(@`$B)*$R-)7N2(`!(BT4028D$)$B+10!(BQ!(A=(/
MA-<```!(C0V,D2``2(D12(L`#[80A-)T$TB#P`&`^B]U\$B)`0^V$(32=>U(
MA=MT"$B)W^B/_/__Z-K\__](@ST2CR````^$I@```$B-'0V-(`!(C04&C2``
M2#G#<QM(C5,!2"G02,'H`TR-;,,(_Q-(@\,(3#GK=?5(C3V'_?__Z$+\__](
MC1W3C"``2(T%S(P@`$@YPW,;2(U3`4@IT$C!Z`-,C6S#"/\32(/#"$PYZW7U
M2(T]334``.@(_/__Z#/Y__^+?0A)BQ0D2(MU`.@A,P``B<?H7/O__TB-!;60
M(`!(C0U&D2``2(D(Z3K____H3/W__^E0____@#WFD"```'0!PU/&!=N0(``!
M2(,]:HX@``!T#$B+/8&0(`#HM/S__TB-'4V,(`!(BP-(A<!T"/_02(/#".OP
M2(,]#8X@``!T#$B-/3QW``#H=_S__UO#@#V.D"```'0!PU/&!8.0(``!2(,]
M&XX@``!T$TB--3*0(`!(C3T+=P``Z%[\__](@SW6C2```'022(T][8L@`$B#
M/P!T!>@R_/__2(T=NXL@`$B+`TB#^/]T"/_02(/K".OO6\-!5T%6055!5%53
M2(/L"$B%_P^$F````$B-!9*0(`!,BSA-A?\/A(4````/M@>$P'0$/#UU3T4Q
MY$F+'TB%VW0R28GU28G^36/D3(G]3(GB3(GV2(G?Z";Y__^%P'4'0H`\(SUT
M.$B#Q0A(BUT`2(7;==I(B=A(@\0(6UU!7$%=05Y!7\-)B?Q)@\0!00^V!"2$
MP'0$/#UU[T$I_.N;3"G]2,']`T&);0!*C5PC`>O#,=OKOT%455-(@^P02(G]
M3(LE^XP@`$F+!"1(B40D"#'`2(U<)`1(B=Y(B>\QP.@>____2(7`=#%(8U0D
M!$B-!;V/(`!(BP!(C0302(M0"$B)$$B%TG3/2(/`"$B+4`A(B1!(A=)U\.N]
M2(M$)`A),P0D=0E(@\006UU!7,/HK_K__T%7059!54%455-(@>RX````2(L=
M=XP@`$B+`TB)A"2H````,<!(A?]T"$F)_X`_`'4C2(N$)*@```!(,P,/A0,!
M``!(@<2X````6UU!7$%=05Y!7\/H=?K__TB)Q4B%P'303(TEQS(``$B-1"00
M2(E$)`A(B>_HY/G__TB%P`^$I0```$R-:`VY`@```$R)[DR)Y_.F#Y?`'`"$
MP'35N0,```!,B>Y(C3V",@``\Z8/E\`<`(3`=+M,B?_HW_G__TF)QDR)[^C4
M^?__08U\!@)(8__H5_?__TF)QDR)Z4R)^DB--4HR``!(B<<QP.A]^?__2(MT
M)`A,B??H(/?__TR)]X/X_W00BT0D&"4`\```/0!```!T)^CS]O__3(GWZ-OX
M___I2O___TB)[^A.]___3(G_Z';X___I]/[__Y#HO/[__^O6Z&3Y__]!5T%6
M055!5%532(/L.$B)_4F)]4B+'2F+(`!(BP-(B40D*#'`@#X]=01)@\4!3(GO
MZ![Y__])B<1(C70D)$B)[S'`Z#S]__])B<9(A<`/A.H```!(B<?H^/C__TPY
MX`^#P@```$QC?"0D2<'G`TR--;^-(``/MD4`A,`/A(\!```\/0^$AP$``$B)
MZ.L(@/H]#Q\`=`M(@\`!#[80A-)U[4@IZ$B830,^2HU\(`+H,?;__TF)!TB%
MP`^$9`$``$AC5"0D28L&2(L4T$B-30$/MD4`B`*$P'44ZQ9(@\(!2(/!`0^V
M0?^(`H3`=`0\/77JQ@(],<!!#[9,!0"(3`(!2(/``83)=>XQP$B+="0H2#,S
M#X45`0``2(/$.%M=05Q!74%>05_#28/%`4F#Q@%!#[9%_T&(1O^$P'7KZ\I,
MC37OC"``38L&28,X``^$Q0```$R)P#'2ZP*)RDB#P`B-2@%(@S@`=?&-<@-(
M8_9(P>8#BP6,C"``A<")3"0(=6M,B40D&,<%=8P@``$```!(B??H3?7__TB%
MP`^$@P```$QC5"0(1(E4)!1.C3S5`````$R)5"0(3(GZ3(M$)!A,B<9(B<?H
M*O7__TF)P4F)!HM,)!1,BU0D"$O'1-$(`````(E,)"3IBO[__TR)Q^@A]/__
M28G!28D&2(7`="5,8U0D"$R)T4Z-/-4`````Z\DQP.F/_O__OA`````QR>E/
M____N/_____IW?[__^@R]___55-(@>RH````2(G]2(L=_X@@`$B+`TB)A"28
M````,<!(B>;H>O;__X7`=4B+5"0(@>(`\```@?H`0```=!^!^@"@``!T%TB+
MC"28````2#,+=25(@<2H````6UW#O@(```!(B>_HJ//__X7`#Y3`#[;`Z](Q
MP.O.Z+7V__]!5T%6055!5%532('L*`0``$F)_DF)]TB+!7>((`!(BPA(B8PD
M&`0``#')2(U<)!"Z_P,``$B)WDB-/?\N``#HX?3__X7`#XZ.````28G$C5#_
MB50D#&1(BP0E`````$@#!1^((`!(BRA,8VPD#$*`?"P0`'1/36/L3(GJOB\`
M``!(B=_HC/7__TB%P'0\3(GI2(G:3(GV2(GOZ.;R__](BP7OAR``2(N,)!@$
M``!(,PAU2DB!Q"@$``!;74%<05U!7D%?PT6%[76O3(GZ3(GV2(GOZ"WT___K
MQ61(BP0E`````$@#!9N'(`!(BRA,B?I,B?9(B>_H"O3__^NBZ+/U__]54TB!
M[!@$``!(B?Y(BRV`AR``2(M%`$B)A"0(!```,<!(B>.Z``0``$B)W^@2]/__
M2(/H`4@YV'<.ZQ'&``!(@^@!2#G8=`6`."]T[[XO````2(G?Z`GS__](A<!T
M*D@YV'<@2(G?Z"?S__](BXPD"`0``$@S30!U,DB!Q!@$``!;7</&``#KVTB+
MA"0(!```2#-%`'452(T]EBT``$B!Q!@$``!;7>GG\O__Z`+U__](@^P(9$B+
M!"4`````2`,%OH8@`$B-#<=M``!(BQ78AB``2(TU="T``$B+.$B#Q`CI7?3_
M_U-D2(L$)0````!(`P6,AB``2(G#2(LXZ*____]%,<E,C07>+@``3(G!2(T5
MCPT``$B--4TM``!(BSM;Z7WQ__\QP,-!5T%6055!5%532('LV`0``$B)^TF)
M]$B+!4R&(`!(BQ!(B90DR`0``#'22(UT)!Q(C3T?+0``,<#H;/C__TB)Q;XO
M````2(G?Z'SR__](A<!T/DB)WDB-/0(M```QP.C"^O__2(G82(L5_(4@`$B+
MC"3(!```2#,*#X5Z`0``2('$V`0``%M=05Q!74%>05_#3(GGZ-'Q__](C37,
M+```2(G'Z(+S__])B<5(A<!THTR-I"3`````3(UT)"!!@'T```^$TP```$B%
M[7033(GN2(GOZ.+P__^%P`^$E@```$R)[^B2\___28G'28U$!?]).<5S(X`X
M+W0'ZQR`."]U#,8``$B#Z`%).<5U[TR)[^AE\___28G'2(G?Z%KS__])C40'
M`4@]_P,```^'(O___TB)'"1,C0T7+0``38GH2(T-,"T``+H`!```,?9,B><Q
MP.AS\O__3(GV3(GGZ)CP__^%P'40BT0D*"4`\```/0"```!T5DB-->\K```Q
M_^BF\O__28G%2(7`#X3#_O__08!]```/A2W___](A>UT&KD"````2(GN2(T]
M7"L``/.F#Y?`'`"$P'2\0;\!````3(TM1"L``.E,____O@$```!,B>?HD>__
M_X7`=9E,B>9(C3UX*P``Z#KY__],B>?H=O#__^EN_O__D.B+\O__4TB)^[XO
M````Z"WP__](A<!T!$B-6`%(B=];Z4OP__](A?]T(X`_`'0>4TB)^^A(\O__
M2(/``4@]``0``'<52(G?6^F0_/__2(T]O2H``.D7\/__,<!;PU532(/L&$B+
M+0:$(`!(BT4`2(E$)`@QP$B-/?@J``#HXO;__TB-/?4J```QP.C4]O__2(T]
M[RH``#'`Z,;V__](C3WJ*@``,<#HN/;__TB-/>,J```QP.BJ]O__2(T]Y2H`
M`#'`Z)SV__](C3V.*@``,<#HCO;__TB-/=4J```QP.B`]O__2(T]T2H``#'`
MZ'+V__](C3W-*@``,<#H9/;__TB-/5\J```QP.A6]O__2(U<)`1(B=Y(C3VS
M*@``,<#HC?7__TB%P'012(G&2(T]B2H``#'`Z//W__](B=Y(C3V=*@``,<#H
M9O7__TB%P'012(G&2(T]F2H``#'`Z,SW__](B=Y(C3V3*@``,<#H/_7__TB%
MP'0X2(G&2(T]W"D``#'`Z*7W__](C360*@``2(T]`"H``#'`Z)#W__](BT0D
M"$@S10!U,$B#Q!A;7<-(B=Y(C3U5*@``,<#H\?3__TB%P'3#2(G&2(T]XRD`
M`#'`Z%?W___KL.BT\/__4TB#[!!(BQV(@B``2(L#2(E$)`@QP$B-="0$2(T]
MLRD``.BM]/__2(7`=!$/M@"$P'0*/#`/E<`/ML#K`C'`2(M4)`A(,Q-U!DB#
MQ!!;P^A@\/__2('LV````$B)="0H2(E4)#!(B4PD.$R)1"1`3(E,)$B$P'0W
M#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD`````\IK"2@````#RFT)+``
M```/*;PDP````$B+!=Z!(`!(BPA(B4PD&#')QP0D"````,=$)`0P````2(V$
M).````!(B40D"$B-1"0@2(E$)!!(B>)(B?Y(BP69@2``2(VX,`$``.C%[?__
MO_\```#H2^[__T%6055!5%532('L$``!`$&)_$R++7*!(`!)BT4`2(F$)`@`
M`0`QP+H"````,?;HB.S__TB-:/](NO__``````"`2"'J>0](@^H!2('*``#_
M_TB#P@%(*=4/B*D```!(B>-,C373*```,=)(B>Y$B>?H1NS__TB#^/\/A)$`
M``"Z"``!`$B)WD2)Y^C\[?__2&/0@_C_=$Y(@_H'=E9(C403^$@YV'),2(T5
M58,@`.L)2(/H`4@YV'(Z2(L*2#D(=>](*=U(`>A(B[0D"``!`$DS=0!U2DB!
MQ!```0!;74%<05U!7L-(C3U<*```,<#H6/[__TB![0```0!(@?T``/__#X5A
M____2,?`_____^NW3(GW,<#H,?[__^E@____Z(?N__](@^P(Z([N__^)Q^AW
M[/__2(7`=`A(BP!(@\0(PS'`Z_=!54%455-(@^P828G\2(LM,H`@`$B+10!(
MB40D"#'`2(UT)`1(C3WD)P``Z%;R__](A<!T"$B)PX`X`'4G3(GF2(T]R"<`
M`#'`Z+3T__](BT0D"$@S10!U7$B#Q!A;74%<05W#3(GGZ.KM__])B<5(B=_H
MW^W__TF-?`4"Z&7K__])B<5)B=A(C0VZ)@``3(GB2(TUNB<``$B)QS'`Z(3M
M__],B>Y(C3UC)P``,<#H3_3__^N9Z*SM__]!5T%6055!5%532('LB`$``$F)
M_DB+!7%_(`!(BPA(B8PD>`$``#')2(T%0B<``$B)1"0P2(T%\B4``$B)1"0X
M2,=$)$``````2(T%OB8``$B)1"1P2(T%JR8``$B)1"1X2(T%#R<``$B)A"2`
M````2(T%K28``$B)A"2(````2(T%^28``$B)A"20````2,>$))@`````````
M2(T%Q"8``$B)1"102(T%UB8``$B)1"182,=$)&``````2(UL)"Q(B>Y(C3VN
M)0``,<#H^_#__TB%P'0)@#@`#X4@`@``,<#H/_[__TF)Q$B%P`^$5P(``$R)
MY^BB[/__2(U\``'H*.K__TB)PT&`/"0`="M)B=U,C3UT)@``00^V%"1,B?Y,
MB>\QP.A"[/__28/$`4F#Q0)!@#PD`'7?3(UD)'!(C3W))0``ZQ%)@\0(28L\
M)$B%_P^$6`$``$B)[C'`Z&KP__])B<=(A<!TW8`X`'382(G'Z`/U__^%P'3,
M3(G_Z`GJ__](B<)(A<`/A"$!``!(B=&+,4B#P02-AO_^_O[WUB'P)8"`@(!T
MZ8G&P>X0J8"````/1,9(C7$"2`]$SHG&0`#&2(/9`T@IT4B)WHL^2(/&!(V'
M__[^_O?7(?@E@("`@'3I2(E4)!B)Q\'O$*F`@```#T3'2(U^`D@/1/>)P@#"
M2(/>`T@IWD2-O#$$!```36/_3(G_Z!#I__])B<1)B=E,C05H)0``2(T-124`
M`$B+5"082(TU6B4``$B)QS'`Z";K__^^P`$``$R)Y^AIZO__@_C_#X1.`0``
M2(VT)*````!,B>?HL.K__XG#A<!U%XN$)*@````E`/```#T`0```#X1E`0``
M3(GA28L62(TUMB4``$B+!>=\(`!(C;@P`0``,<#HL>G__T4Q_^ML13'_26/'
M3(MDQ#!-A>1T.$&`/"0`=#%,B>?HJ_/__T&#QP&%P'3<3(GGZ*WH__](B<)(
MA<`/A:3^__])8\=,BV3$,$V%Y'7(,=+ID/[__TB)QTB)1"08Z#K\__](BT0D
M&$B)Q^ASZ/__28G'3(GX2(L-9GP@`$B+G"1X`0``2#,9#X5B`P``2('$B`$`
M`%M=05Q!74%>05_#2(T]%20``#';2(7_="1(B>XQP.AK[O__@\,!2(7`=`6`
M.`!U)DACPTB+?,102(7_==R_#0```.BGY___2(G#3(TEVR,``.EZ_?__2(G'
MZ/#G__])B<1(A<`/A4K]___KQ&:0Z'OF__^#.!$/A*+^__]FD.AKYO__1(L`
M3(GA28L62(TU.R0``$B+!:Q[(`!(C;@P`0``,<#H=NC__T4Q_^DN____BX0D
MO````$&)Q>B_Z?__03G%#X6#_O__BX0DJ````"7_`0``/<`!```/A6S^__],
MB?_H!^?__TF)QTB)[DB-/2XC```QP.B3[?__2(7`#X0S`0``2(G&28L^Z-7T
M__](B<5(A<`/A!P!``!(B>_H.^G__X/X`WXY2&/02(UT%?RY!0```$B-/24C
M``#SI@^7PH#:`(32=1F#^`0/A,@!``"#Z`1(F(!\!?\O#X2X`0``,<#H4OC_
M_X7`=10Q]DB)[^CHYO__B<6%P`^%OP```$B--74B``!(C3T!(@``,<#H=>__
M_^CTY?__08G`3(T-`2,``$B-#8PB``!,B>)(C370(@``3(G_,<#H;^C__TB-
M+=\B``#K-^@AY?__@S@1=3^#PP'HM.7__T&)P$B)+"1!B=E(C0U,(@``3(GB
M2(TUGB(``$R)_S'`Z"_H__^^P`$``$R)_^ARY___@_C_=+=,B>?HI>?__TR)
M_DB-/1<A```QP.C@[O__3(G_Z-;Y___II_W__TF++NG<_O__B<?H??C__TF)
MQDB%P`^(+O___TB-</8QTHGOZ!_E__](C;0D.@$``+H&````B>_HV^;__TB#
M^`9T#DB-/>LA```QP.B']___BP6Y8```.80D.@$```^%YO[__P^W!:E@``!F
M.80D/@$```^%T?[__TF-=LXQTHGOZ,+D__](C9PD0`$``+HH````2(G>B>_H
M>^;__TB#^"AT#DB-/8LA```QP.@G]___QH0D:`$```!,C0VO(0``28G82(T-
M-R$``$R)XDB--6PA``!,B?\QP.@:Y___Z?C^__]-BW8(387V#X0[_O__3(GW
MZ##G__](@_@##X8I_O__28UT!ORY!0```$B-/1TA``#SI@^7P!P`A,!)#T3N
MZ0;^___H#N?__T%505154TB#[!A,BR7=>"``28L$)$B)1"0(,<!D2(L$)0``
M``!(`P6R>"``2(L`#[:0L````(B0L0```$B-;"0$2(GN2(T]R!\``#'`Z-SJ
M__](A<!T"8`X,0^$?`$``#'`Z'3T__]D2(L$)0````!(`P5G>"``28G%N0,`
M``"Z`0```$B--;D@``!(BSCHJ^3__TB)PTB%P'0H2(M`$$B-%:`@``!(BS!)
MBWT`Z*SD__](BT,02(LP]D8.0`^%0P$``&1(BP0E`````$@#!0MX(`!)B<6Y
M`P```+H!````2(TU9"```$B+..A/Y/__2(G#2(7`="U(B>Y(C3WB'@``,<#H
M)NK__TB%P`^$V@```$B+2Q!(B<)(BS%)BWT`Z#KD__]D2(L$)0````!(`P6J
M=R``2(G#N@$```!(C34*(```2(LXZ(/B__](C140(```2(G&2(L[Z`'D__](
MBP/&@+$`````2(GN2(T]:1X``#'`Z+;I__](B04W>B``2(7`=#2^P`$``$B)
MQ^B-Y/__@_@1=`B-4`&#^@%W=DB+1"0(23,$)`^%B````$B#Q!A;74%<05W#
M2(L]_WD@`.B>]___2(D%ZWD@`$B%P'6T2(T]+R```.@RXO__@'@!``^$@?[_
M_^EU_O__2(M#$$B+%<AY(`!(BS)(BSCH6.[__^D>____28M]`.A/XO__Z:_^
M__^)P4B+%9EY(`!(BP6:>2``2(LP2(T]`"```#'`Z-GA___HU.3__U-(B?LQ
MP.@5]/__A<!T"DB%VW0%@#L`=0);PTB)W^A&\O__2(G'Z![R__^Y!````$B-
M/8(>``!(B<;SI@^7P!P`A,!UU$B)WUOIU^G__V8/'T0``$%7059!54%455-(
M@>R8`@``2(L%2'8@`$B+&$B)G"2(`@``,=M,C4\X13'`2(GA0XL$`0_(2XLT
M`8G`2HD$04B)\DC!ZB!(B?!(P>@H)0#_``!(P>XX2`GP2(G62,'F&(GV2`GP
M2,'B"('B``#_`$@)T$J)1$$(28/`"$F#^$!UKDB-L0`"``!(BT%H2#-!0$@S
M01!(,P%(C10`2,'H'T@)T(/@_TB)@8````!(@\$(2#GQ==-,BQ=,BT\(2(M?
M$$B+;QA,B=!(P>`%3(G22,'J&T@)T`,$)$B+=R"-E#"9>8):2(G82#'H3"'(
M2#'H1(TD`DR)R4C!X1Y,B<A(P>@"2`G!08G(2(G83#'`3"'02#'82(M4)`A(
MC905F7F"6D@!T$R)XDC!X@5,B>9(P>X;2`GR1(T<`DR)TDC!XAY,B=!(P>@"
M2`G"B=9(,=%,(>%,,<%(BT0D$$B-A`.9>8):2`'!3(G82,'@!4V)W4G![1M,
M">A$C2P(3(G@2,'@'DG![`),">")P4@QPDPAVD@Q\DR+9"083XV$()EY@EI,
M`<)-B>A)P>`%38GL2<'L&TT)X$6-)!!-B=A)P>`>2<'K`DT)V$2)PDPQP$PA
MZ$@QR$R+7"0@2HVT'IEY@EI(`?!,B>9(P>8%38GC2<'K&TP)WD2-'`9,B>Y(
MP>8>2<'M`DP)[HGP23'P32'@23'03(ML)"A*C8PIF7F"6DP!P4V)V$G!X`5-
MB=U)P>T;30GH18TL"$R)X4C!X1Y)P>P"3`GA08G(2#'.3"'>2#'&3(MD)#!*
MC90BF7F"6D@!\DR)[DC!Y@5-B>Q)P>P;3`GF1(TD%DR)VDC!XAY)P>L"3`G:
MB=9(,=%,(>E,,<%,BUPD.$J-A!B9>8):2`'(3(GA2,'A!4V)XTG!ZQM,"=E$
MC1P!3(GH2,'@'DG![0),">B)P4@QPDPAXD@Q\DR+;"1`3XV$*)EY@EI,`<)-
MB=A)P>`%38G=2<'M&TT)Z$6-+!!-B>!)P>`>2<'L`DT)X$2)PDPQP$PAV$@Q
MR$R+9"1(2HVT)IEY@EI(`?!,B>Y(P>8%38GL2<'L&TP)YD2-)`9,B=Y(P>8>
M2<'K`DP)WHGP23'P32'H23'03(M<)%!*C8P9F7F"6DP!P4V)X$G!X`5-B>-)
MP>L;30G818T<"$R)Z4C!X1Y)P>T"3`GI08G(2#'.3"'F2#'&3(ML)%A*C90J
MF7F"6D@!\DR)WDC!Y@5-B=U)P>T;3`GN1(TL%DR)XDC!XAY)P>P"3`GBB=9(
M,=%,(=E,,<%,BV0D8$J-A""9>8):2`'(3(GI2,'A!4V)[$G![!M,">%$C20!
M3(G82,'@'DG!ZP),"=B)P4@QPDPAZD@Q\DR+7"1H3XV$&)EY@EI,`<)-B>!)
MP>`%38GC2<'K&TT)V$6-'!!-B>A)P>`>2<'M`DT)Z$2)PDPQP$PAX$@QR$R+
M;"1P2HVT+IEY@EI(`?!,B=Y(P>8%38G=2<'M&TP)[D2--`9,B>9(P>8>2<'L
M`DP)YHGP23'P32'823'03(MD)'A*C8PAF7F"6DP!P4V)\$G!X`5-B?1)P>P;
M30G@18TD"$R)V4C!X1Y)P>L"3`G908G+2#'.3"'V2#'&3(N$)(````!*C90"
MF7F"6D@!\DR)YDC!Y@5-B>!)P>@;3`G&1(TL%DR)\DC!XAY)P>X"3`GRB=9(
M,=%,(>%,,=E,BX0DB````$J-A`"9>8):2`'(3(GI2,'A!4V)Z$G!Z!M,"<%$
MC00!3(G@2,'@'DG![`),">")P4@QPDPAZD@Q\DR+I"20````3XV<(YEY@EI,
M`=I-B<-)P>,%38G$2<'L&TT)XT6)VTP!VD&)U$V)ZTG!XQY)P>T"30GK3#'8
M3"'`2#'(3(NL))@```!*C;0NF7F"6D@!\$R)YDC!Y@5-B>5)P>T;3`GNB?9(
M`?!!B<9,B<9(P>8>2<'H`DP)QDV)W4DQ]40QZDR+A"2@````2HV,`:'KV6Y(
M`=%,B?)(P>(%38GU2<'M&TP)ZHG23(TL$42)Z4V)X$G!X!Y)P>P"30G@1(G:
M2`.4)*@```!)B?--,<-$,=A(C90"H>O9;DB)R$C!X`5)B<Q)P>P;3`G@B<!,
MC20"18GC3(GR2,'B'DG![@),"?*)\$@#A"2P````3(G&2#'603'U2HVT**'K
MV6Y,B=A(P>`%38G=2<'M&TP)Z(G`2`'P08G%2(G.2,'F'DC!Z0)("<Y$B<%(
M`XPDN````$F)T$DQ\$4QQ$Z-I"&AZ]EN3(GI2,'A!4V)Z$G!Z!M,"<&)R4V-
M!`Q%B<1,B=E(P>$>2<'K`DP)V8G22`.4),````!)B?-),<M$,=A(C90"H>O9
M;DR)X$C!X`5-B>-)P>L;3`G8B<!,C1P"18G>3(GH2,'@'DG![0),">B)\D@#
ME"3(````2(G.2#'&03'P2HVT`J'KV6Y,B?)(P>(%38GP2<'H&TP)PHG23(T$
M%D6)Q4R)XDC!XAY)P>P"3`GBB<E(`XPDT````$B)QD@QUD$Q\TJ-M!FAZ]EN
M3(GI2,'A!4V)ZTG!ZQM,"=F)R4R-'`Y%B=Q,B?9(P>8>2<'N`DP)]HG`2`.$
M)-@```!(B=%(,?%!,<A*C8P`H>O9;DR)X$C!X`5-B>!)P>@;3`G`B<!,C00!
M18G&3(GI2,'A'DG![0),">F)T$@#A"3@````2(GR2#'*03'32HV4&*'KV6Y,
MB?!(P>`%38GS2<'K&TP)V(G`3(T<`D6)W4R)X$C!X!Y)P>P"3`G@B?)(`Y0D
MZ````$B)SD@QQD$Q\$J-M`*AZ]EN3(GJ2,'B!4V)Z$G!Z!M,"<*)TDR-!!9%
MB<1,B?)(P>(>2<'N`DP)\HG)2`.,)/````!(B<9(,=9!,?-*C;09H>O9;DR)
MX4C!X05-B>-)P>L;3`G9B<E,C1P.18G>3(GN2,'F'DG![0),">Z)P$@#A"3X
M````2(G12#'Q03'(2HV,`*'KV6Y,B?!(P>`%38GP2<'H&TP)P(G`3(T$`46)
MQ4R)X4C!X1Y)P>P"3`GAB=!(`X0D``$``$B)\D@QRD$QTTJ-E!BAZ]EN3(GH
M2,'@!4V)[$G![!M,">")P$R-)`)%B>-,B?!(P>`>2<'N`DP)\(GR2`.4)`@!
M``!(B<Y(,<9!,?!*C;0"H>O9;DR)VDC!X@5-B=A)P>@;3`G"B=),C00618G&
M3(GJ2,'B'DG![0),">J)R4@#C"00`0``2(G&2#'603'T2HVT(:'KV6Y,B?%(
MP>$%38GU2<'M&TP)Z8G)3(TL#D6)[$R)WDC!YAY)P>L"3`G>B<!(`X0D&`$`
M`$B)T4@Q\4$QR$J-C`"AZ]EN3(G@2,'@!4V)X$G!Z!M,"<")P$R-!`%%B<-,
MB?%(P>$>2<'N`DP)\8G02`.$)"`!``!(B?)(,<I!,=5.C:PHH>O9;DR)V$C!
MX`5,B=I(P>H;2`G0B<!)C50%`$&)UDR)X$C!X!Y)P>P"3`G@B?9(`[0D*`$`
M`$F)S$DQQ$4QX$Z-I`:AZ]EN3(GV2,'F!4V)\$G!Z!M,"<:)]DV-!#1%B<5-
MB=Q)P>0>2<'K`DT)W(G)2`.,)#`!``!(B<9,,>8Q\DB-C!&AZ]EN3(GJ2,'B
M!4R)[DC![AM("?)$C1P*3(GR2,'B'DG![@),"?*)UHG`2`.$)#@!``!,B>%(
M,=%!,<A*C8P`H>O9;DR)V$C!X`5-B=A)P>@;3`G`1(TT"$V)Z$G!X!Y)P>T"
M30GH1(G!3`G"3"':2(GP2"'(2`G"N-R\&X],BZPD0`$``$D!Q46)Y$T![$P!
MXDV)]$G!Y`5-B?5)P>T;30GL00'43(G:2,'B'DG!ZP),"=I!B=-)"=!-(?!)
MB<U-(=U-">A,BZPD2`$``$D!Q4P![DP!QDV)X$G!X`5-B>5)P>T;30GH18TL
M,$R)]DC!YAY)P>X"3`GV08GP2`GR3"'B38G>32'&3`GR3(NT)%`!``!)`<9,
M`?%(`<I,B>E(P>$%38GN2<'N&TP)\42--!%,B>%(P>$>2<'L`DP)X8G*2`G.
M3"'N38G$22'43`GF3(ND)%@!``!)`<1-`>-,`=Y-B?-)P>,%38GT2<'L&TT)
MXT6-)#--B>M)P>,>2<'M`DT)ZT2)WDP)V4PA\4F)U4DA]4P)Z4R+K"1@`0``
M20'%30'H3`'!38G@2<'@!4V)Y4G![1M-">A%C2P(38GP2<'@'DG![@)-"?!$
MB<%-"<--(>-)B?9)(<Y-"?-,B[0D:`$``$D!QDP!\DP!VDV)ZTG!XP5-B>Y)
MP>X;30GS18TT$TR)XDC!XAY)P>P"3`GB08G320G032'H28G,32'<30G@3(ND
M)'`!``!)`<1,`>9,`<9-B?!)P>`%38GT2<'L&TT)X$6-)#!,B>Y(P>8>2<'M
M`DP)[D&)\$@)\DPA\DV)W4TAQ4P)ZDR+K"1X`0``20'%3`'I2`'*3(GA2,'A
M!4V)Y4G![1M,">E$C2P13(GQ2,'A'DG![@),"?&)RD@)SDPAYDV)QDDAUDP)
M]DR+M"2``0``20'&30'S3`'>38GK2<'C!4V)[DG![AM-"?-%C30S38GC2<'C
M'DG![`)-">-$B=Y,"=E,(>E)B=1)(?1,">%,BZ0DB`$``$D!Q$T!X$P!P4V)
M\$G!X`5-B?1)P>P;30G@18TD"$V)Z$G!X!Y)P>T"30GH1(G!30G#32'S28GU
M22'-30GK3(NL))`!``!)`<5,`>I,`=I-B>-)P>,%38GE2<'M&TT)ZT6-+!-,
MB?)(P>(>2<'N`DP)\D&)TTD)T$TAX$F)SDTAWDT)\$R+M"28`0``20'&3`'V
M3`'&38GH2<'@!4V)[DG![AM-"?!%C30P3(GF2,'F'DG![`),">9!B?!("?),
M(>I-B=Q-(<1,">),BZ0DH`$``$D!Q$P!X4@!RDR)\4C!X05-B?1)P>P;3`GA
M1(TD$4R)Z4C!X1Y)P>T"3`GIB<I("<Y,(?9-B<5)(=5,">Y,BZPDJ`$``$D!
MQ4T!ZTP!WDV)XTG!XP5-B>5)P>T;30GK18TL,TV)\TG!XQY)P>X"30GS1(G>
M3`G93"'A28G622'V3`GQ3(NT)+`!``!)`<9-`?!,`<%-B>A)P>`%38GN2<'N
M&TT)\$6--`A-B>!)P>`>2<'L`DT)X$2)P4T)PTTAZTF)]$DAS$T)XTR+I"2X
M`0``20'$3`'B3`':38GS2<'C!4V)]$G![!M-">-%C2033(GJ2,'B'DG![0),
M">I!B=-)"=!-(?!)B<U-(=U-">A,BZPDP`$``$D!Q4P![DP!QDV)X$G!X`5-
MB>5)P>T;30GH18TL,$R)]DC!YAY)P>X"3`GV08GV2`GR3"'B38G832'P3`G"
M3(N$),@!``!)`<!,`<%(`<I,B>E(P>$%38GH2<'H&TP)P42-!!%,B>%(P>$>
M2<'L`DP)X4&)S$@)SDPA[DR)\DPAXD@)UDB+E"30`0``2`'"3`':2`'63(G"
M2,'B!4V)PTG!ZQM,"=J)TD@!UD&)\TR)ZDC!XAY)P>T"3`GJ08G72`G13"'!
M38GE32']3`GI2`.$)-@!``!,`?!(`<A,B=E(P>$%38G=2<'M&TP)Z8G)2`'(
M08G%3(G!2,'A'DG!Z`))"<A,,<(QUKG6P6+*2(N4).`!``!(`<I,`>)(`?),
MB>Y(P>8%38GL2<'L&TP)YHGV2`'RB=9-B=Q)P>0>2<'K`DT)XTV)Q$TQW$0Q
MX$R+M"3H`0``20'.3XTD/DD!Q$B)\$C!X`5)B?9)P>X;3`GPB<!)`<1%B>9,
MB>A(P>`>2<'M`DD)Q4B+A"3P`0``2`'(18G`3`'`38G833'H1#'"2`'"3(GP
M2,'@!4V)\$G!Z!M,"<")P$@!PD&)T$B)\$C!X!Y(P>X"2`G&2(N$)/@!``!(
M`<A%B=M,`=A-B>M),?-%,>-)`<-,B<!(P>`%38G$2<'L&TP)X(G`20'#18G<
M3(GP2,'@'DG![@),"?!,B[0D``(``$D!SD6)[4T!]4F)]DDQQD0Q\DD!U4R)
MXDC!X@5-B>9)P>X;3`GRB=))`=5%B>Y,B<)(P>(>2<'H`DD)T$B+E"0(`@``
M2`'*B?9(`?)(B<9,,<9!,?-)`=-,B?)(P>(%3(GV2,'N&T@)\HG220'318G?
M3(GF2,'F'DG![`),">9(BY0D$`(``$@!RHG`2`'038G$23'T13'L20'$3(GX
M2,'@!4R)^DC!ZAM("=")P$D!Q$6)Y4R)\$C!X!Y)P>X"20G&2(N$)!@"``!(
M`<A%B<!,`<!)B?!-,?!%,=A)`<!,B>A(P>`%3(GJ2,'J&T@)T(G`20'`18G#
M3(GZ2,'B'DG![P),"?I(BX0D(`(``$@!R(GV2`'P3(GV2#'603'T20'$3(G8
M2,'@!4R)WDC![AM("?")P$D!Q$6)YTR)Z$C!X!Y)P>T"20G%2(N$)"@"``!(
M`<A%B?9,`?!(B=9,,>Y!,?!)`<!,B?A(P>`%3(G^2,'N&T@)\(G`20'`18G&
M3(G82,'@'DG!ZP),"=A(B[0D,`(``$@!SHG22`'R38GK23'#13'C20'33(GR
M2,'B!4R)]DC![AM("?*)TDD!TT6)W$R)^DC!XAY)P>\"20G72(N4)#@"``!(
M`<I%B>U,`>I(B<9,,?Y!,?!)`=!,B>)(P>(%3(GF2,'N&T@)\HG220'018G%
M3(GV2,'F'DG![@),"?9(BY0D0`(``$@!RHG`2`'03(GZ2#'R03'320'#3(GH
M2,'@!4R)ZDC!ZAM("=")P$D!PT6)WDR)X$C!X!Y)P>P"20G$2(N$)$@"``!(
M`<A%B?],`?A(B?),,>)!,=!)`<!,B?!(P>`%3(GR2,'J&T@)T(G`20'`18G'
M3(GJ2,'B'DG![0),">I(BX0D4`(``$@!R(GV2`'P3(GF2#'61#'>2`'&3(GX
M2,'@!4V)^TG!ZQM,"=B)P$@!QD&)\TR)\$C!X!Y)P>X"20G&2(N$)%@"``!(
M`<A%B>1,`>!)B=1-,?1%,<1)`<1,B=A(P>`%38G82<'H&TP)P(G`20'$18G@
M3(GX2,'@'DG![P),"?A,BZPD8`(``$D!S8G23`'J38GU23'%1#'N2`'63(G"
M2,'B!4V)Q4G![1M,">J)TD@!UD&)]4R)VDC!XAY)P>L"20G32(N4)&@"``!(
M`<I%B?9,`?))B<9-,=Y%,?1,`>)-B>Q)P>0%38GN2<'N&TT)]$6)Y$P!XD&)
MU$V)QDG!YAY)P>@"30GP3(NT)'`"``!)`<Z)P$P!\$V)WDTQQD0Q]D@!\$R)
MYDC!Y@5-B>9)P>X;3`GV`<9,B>A(P>`>2<'M`DD)Q4R)X$C!X!Y)P>P"20G$
M2`.,)'@"``!$B=A(`<%,B<!,,>@QPDB-!!%(B?)(P>(%2(GQ2,'I&T@)R@'0
M00'"3(D71`'.2(EW"$0!XTB)7Q!$`>U(B6\81`-'($R)1R!(BP6,8"``2(N<
M)(@"``!(,QAU$DB!Q)@"``!;74%<05U!7D%?P^B(SO__2(/L"+^`````Z/K+
M__](QP`!(T5GNHFKS>](B5`(N?[<NIA(B4@02,=`&'94,A"^\.'2PTB)<"!(
MQT`H`````$C'0#``````QT!X`````$B#Q`C#05=!5D%505154TB#[`A)B?Q(
MB?-(8\))B<5(BW<HC0S&2(M7,$@Y\4B#T@!(B4\H2,'H'4@!T$B)1S!(8W]X
M28UL)#B%_W100;]`````02G_13G]10]._4UC]T@![TR)\DB)WNB;S?__08M$
M)'A$`?A!B40D>(/X0'0/2(/$"%M=05Q!74%>05_#12G]3`'S3(GGZ!SI__]!
M@_T_?G!!@^U`18GO0<'O!D6)_DF#Q@%)P>8&20'>2(L#2(E%`$B+0PA(B44(
M2(M#$$B)11!(BT,82(E%&$B+0R!(B44@2(M#*$B)12A(BT,P2(E%,$B+0SA(
MB44X2(/#0$R)Y^BRZ/__3#GS=;!!P><&12G]26/%2(GO2(G>2(/X"',DJ`1T
M`:6H`G0"9J6H`70!I$6);"1X2(/$"%M=05Q!74%>05_#0/;%`75:0/;'`G4N
M0/;'!'4\2(/X"'+$2(G!2(/A^#'23(L$%DR)!!=(@\((2#G*<N](`==(`=;K
MH@^W%F:)%TB#QP)(@\8"2(/H`NN^BQ:)%TB#QP1(@\8$2(/H!.NR#[8308A4
M)#A(@\<!2(/&`4B#Z`'KD$%6055!5%532(G]2(GS3(MF*$R+=C!,B>!(P>@#
M@^`_3(UN.(U0`4B80<9$!0"`2&/Z3`'O@_HX#XZW`0``N$`````IT'0/,=*)
MT<8$#P"#P@$YPG+S2(G?Z)_G__],B>^Y.````#'`0?;%`0^%7@(``$#VQP(/
MA4H"``!`]L<$#X4W`@``08G(08/@X#'2B=9(B00W2(E$-PA(B40W$$B)1#<8
M@\(@1#G"<N-(`=?VP1!T!$BK2*OVP0AT`DBK]L$$=`&K]L$"=`)FJX/A`0^%
M4P$``$R)\$C!Z!B(0W!,B?!(P>@0B$-Q3(GP2,'H"(A#<D2(<W-,B>!(P>@8
MB$-T3(G@2,'H$(A#=4R)X$C!Z`B(0W9$B&-W2(G?Z-SF__](BP-(P>@8B$4`
M2(L#2,'H$(A%`4B+`TC!Z`B(10)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0
MB$4%2(M#"$C!Z`B(109(BT,(B$4'2(M#$$C!Z!B(10A(BT,02,'H$(A%"4B+
M0Q!(P>@(B$4*2(M#$(A%"TB+0QA(P>@8B$4,2(M#&$C!Z!"(10U(BT,82,'H
M"(A%#DB+0QB(10](BT,@2,'H&(A%$$B+0R!(P>@0B$412(M#($C!Z`B(11)(
MBT,@B$432(G?6UU!7$%=05[IV,G__[@X````*=")PC'`@_H@<RWVPA`/A8H`
M``#VP@AU?/;"!'5J]L("9I!U5H/B`0^$K?[__ZH/'T``Z:/^__]`]L<!=7Q`
M]L<"D'5H0/;'!'5I@_H@<KM!B=!!@^#@,<F)SDB)!#=(B40W"$B)1#<02(E$
M-QB#P2!$.<%RXT@!S^N09JN#X@$/A%7^___KIJOVP@)TEP\?1```Z^9(J_;"
M!'2"Z^I(JTBK]L((#X1N____Z^AFJX/J`NN1JX/J!.N1JH/J`>E[____JX/I
M!.G`_?__9JN#Z0+IK/W__ZJY-P```.F7_?__05154TB#[#")?"0<2(ET)!!(
MB50D"$B+'65;(`!(BP-(B40D*#'`2(U4)`A(C70D$$B-?"0<Z.?'__](BS5H
M6R``2(GR2(L]5EL@`.B1QO__2(L%^EH@`(`X`'4WZ&#'__](B07Q72``2(7`
M#X2)`0``2(G'Z!C(__]D2(L$)0````!(`P7H6B``2(L`QH!>"````&1(BP0E
M`````$@#!<Y:(`!(BP"`B-H#```#BT0D'(UH`XUX!$AC_TC!YP/HKL?__TB)
M!8==(`!(BWPD$$B+%TB)$$B-#1\#``!(B4@(2(T5(ET@`$B+$DB)4!!(C0T)
M`P``2(E(&$2+1"0<08/X`0^.PP```$B#QPA!@\`#O@0```!(BP](8]9(B0S0
M2(/'"(/&`40YQG7J2&/V2,'F`TC'!#``````13'`2(G!B>I(C36+T___2(L]
M"5T@`.@,QO__A<!T9$B+/?E<(`#HG,;__T&)Q$B-;"0D2(GN2(T]/P$``#'`
MZ$/,__](A<!T)TB+/<]<(`#H\L?__^B=Q/__1(G@2(M,)"A(,PMU5$B#Q#!;
M74%<PTB+/9A<(`!(A?]T'^@2X___Z\9(BSV57"``Z)C&___KCKX@````Z5W_
M__](B>Y(C3V.````Z-W+__](B<=(B05;7"``2(7`=)#KP>BGQ___OP$```#H
M/<;__P````````````````!(@^P(Z.O*__](@\0(PP``+BX`)7,O)7,`+W!R
M;V,O8W5R<')O8R]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`%!%
M4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!0
M05)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL
M960`<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T
M;7`O`%1%35!$25(`5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P
M87)L`"YP87(`<VAO<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE
M=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-C,`+64`+2T`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F
M<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'
M24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C
M('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)
M0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H
M)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H
M)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@
M82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2![
M"G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I
M>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*
M?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI
M.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]
M/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP
M+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP
M.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE
M(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M
M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R
M;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G
M;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@
M17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q
M6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2
M(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO
M=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO
M=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L
M("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K
M*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S
M(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B
M=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F
M:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@
M(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO
M9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB
M:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K
M*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN
M9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@
M)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)
M4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E
M8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@
M<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T[
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P
M87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@
M<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D
M4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*
M<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@
M96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO
M861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L
M('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@
M("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X[
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I
M;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O
M6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R
M:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO
M8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@
M/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L
M>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=
M.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I
M('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F
M("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN
M="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA
M;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H
M+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#
M2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE
M<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D
M>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B
M17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@
M(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY
M("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I
M*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D
M9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@
M,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@
M<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E
M("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y
M<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M
M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)0
M05)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.
M5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``0T%#2$4``'!E
M<FQX<VDN8P````$;`SL0`0``(0```(2#___$`0``1(?__^P!``"$A___+`$`
M`+^'__]4`0``^8?__X`!```YB?__F`$``#2+__\$`@``YXO__U`"``!EC/__
MA`(``+"-___0`@``XH___QP#``!?D/__2`,``&&1__^4`P``$I+__\P#``!'
MDO__Y`,``(>2__\`!```BI+__Q0$``")E/__8`0``*F4__]\!```X93__Z`$
M``!@EO__S`0``+26___P!```:9?__P@%``"-F/__4`4``*Z8__]L!0``:)G_
M_Z@%```&H/__^`4``$"B__\T!@``E*+__XP&``",N/__W`8``."X___T!@``
ME[K__U@'``!RO?__5`8``!0``````````7I2``%X$`$;#`<(D`$``"0````<
M````4(;__SL`````00X0A@)!#AB#`T0.('(.&$$.$$$."``H````1````&.&
M__\Z`````$(.$(P"00X8A@-!#B"#!&T*#AA!#A!"#@A!"Q0```!P````<8;_
M_T`!`````SL!#A```"@```"(````F8?__S\!````0@X0C0)"#AB,`T$.((8$
M00XH@P5$#C``````)````+0```"X@?__P`,````.$$8.&$H/"W<(@``_&CLJ
M,R0B`````!0```#<````4(7__R```````````````$@```#T````*(G__[,`
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FL*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A!"P`P````0`$``(^)__]^`````$(.$(P"00X8A@-!
M#B"#!$0.,`)L"@X@00X800X00@X(00L`2````'0!``#9B?__2P$```!"#A"/
M`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#O`!>0H..$$.,$$.*$(.($(.
M&$(.$$(."$$+`$@```#``0``V(K__S("````0@X0CP)"#AB.`T(.((T$0@XH
MC`5!#C"&!D$..(,'1`YP`PX!"@XX00XP00XH0@X@0@X80@X00@X(00LH````
M#`(``+Z,__]]`````$$.$(8"00X8@P-'#L`!`E$*#AA!#A!!#@A!"T@````X
M`@``#XW__P(!````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[@
M"`*I"@XX00XP00XH0@X@0@X80@X00@X(00LT````A`(``,6-__^Q`````$$.
M$(8"00X8@P-'#K`(`G@*#AA!#A!!#@A!"V$*#AA!#A!!#@A%"Q0```"\`@``
M/H[__S4`````1`X0;`X(`!@```#4`@``6X[__T``````00X0@P)Z#@@````0
M````\`(``'^.__\#`````````$@````$`P``;H[___\!````0@X0CP)"#AB.
M`T(.((T$0@XHC`5!#C"&!D$..(,'1PZ0"@)U"@XX00XP00XH0@X@0@X80@X0
M0@X(00L8````4`,``"&0__\@`````$$.$(,"6@X(````(````&P#```ED/__
M.`````!+#A"#`EC##@A1#A"#`D,."```*````)`#```YD/__?P$```!!#A"&
M`D$.&(,#1`XP`T@!"@X800X000X(00L@````O`,``(R1__]4`````$$.$(,"
M1`X@`D@*#A!!#@A!"P`4````X`,``+R1__^U`````$<.X`$```!$````^`,`
M`%F2__\D`0```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'#L"`!`+-"@XP
M00XH00X@0@X80@X00@X(00L````8````0`0``#63__\A`````$0.$%@*#@A!
M"P``.````%P$```ZD___N@````!"#A"-`D(.&(P#00X@A@1!#BB#!40.0`)3
M"@XH00X@00X80@X00@X(00L`3````)@$``"XD___G@8```!"#A"/`D(.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#L`#`RT#"@XX00XP00XH0@X@0@X80@X0
M0@X(00L````X````Z`0```::__\Z`@```$(.$(T"0@X8C`-!#B"&!$$.*(,%
M1`Y``Z<!"@XH00X@00X80@X00@X(00L<````)`4```2<__].`````$$.$(,"
M60H."$$+;@X(`#0```!$!0``%K?__P4"````0@X0C`)!#AB&`T$.((,$1`Y0
M`YX!"@X@00X800X00@X(00L`````3````'P%````G/__^!4```!"#A"/`D(.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`]<5"@XX00XP00XH0@X@0@X8
M0@X00@X(00L````4````S`4``*BQ__]4`````$0.$`)/#@A@````Y`4``.2Q
M__^W`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)Q"@XX
M00XP00XH0@X@0@X80@X00@X(00L"K`H..$$.,$$.*$(.($(.&$(.$$(."$$+
M/````$@&```WL___VP(```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&`^$!
M"@XH00X@0@X80@X00@X(10L`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````+L"`````````0``````
M``#%`@````````$`````````TP(````````!`````````/D"````````#P``
M``````!F!`````````P`````````4!H````````-`````````&!6````````
M!`````````!(`@````````4`````````J`X````````&`````````&`%````
M````"@````````"M!`````````L`````````&``````````5````````````
M`````````P``````````L"````````(`````````B`4````````4````````
M``<`````````%P````````#`%`````````<`````````6!,````````(````
M`````&@!````````"0`````````8`````````/O__V\`````````"`````#Y
M__]O``````0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````X*T@````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#@K2````````````````````````````!V&@```````(8:
M````````EAH```````"F&@```````+8:````````QAH```````#6&@``````
M`.8:````````]AH````````&&P```````!8;````````)AL````````V&P``
M`````$8;````````5AL```````!F&P```````'8;````````AAL```````"6
M&P```````*8;````````MAL```````#&&P```````-8;````````YAL`````
M``#V&P````````8<````````%AP````````F'````````#8<````````1AP`
M``````!6'````````&8<````````=AP```````"&'````````)8<````````
MIAP```````"V'````````,8<````````UAP```````#F'````````/8<````
M````!AT````````6'0```````"8=````````-AT```````!&'0```````%8=
M````````9AT```````!V'0```````(8=````````EAT```````"F'0``````
M`+8=````````QAT```````#6'0```````.8=````````]AT````````&'@``
M`````!8>````````B+(@``````#XL2``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````I005(N<&T*``````````!860```````$=#0SH@*$YE=$)3
M1"!N8C0@,C`R,#`X,3`I(#<N-2XP`$=#0SH@*&YB-"`R,#(P,#@Q,"D@-RXU
M+C``)$YE=$)31#H@8W)T,"Y3+'8@,2XT(#(P,3@O,3$O,C8@,3<Z,S<Z-#8@
M:F]E<F<@17AP("0`)$YE=$)31#H@8W)T,"UC;VUM;VXN8RQV(#$N,C,@,C`Q
M."\Q,B\R."`R,#HQ,CHS-2!C:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1I
M+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP,3HS-2!J;V5R9R!%>'`@)``D3F5T
M0E-$.B!C<G1B96=I;BY3+'8@,2XR(#(P,3`O,3$O,S`@,3@Z,S<Z-3D@:F]E
M<F<@17AP("0`)$YE=$)31#H@8W)T96YD+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q
M.#HP,3HS-"!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1N+E,L=B`Q+C$@,C`Q
M,"\P."\P-R`Q.#HP,3HS-2!J;V5R9R!%>'`@)`#QSP(`````````````````
M"`````@````(````"````!L````!```````````J*BH@3F\@3&%B96P@4')O
M=FED960@*BHJ``#QSP(`````````````````"`````@````(````"````!L`
M```!```````````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A
M>``N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T
M+G!L=``N9&%T80`N8G-S`"YC;VUM96YT`"Y354Y77V-T9@``````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````(``````````@```````!<`
M```````````````````!````````````````````$P````<````"````````
M`!@"````````&`(````````8````````````````````!```````````````
M`````"8````'`````@`````````P`@```````#`"````````%```````````
M``````````0````````````````````W````!0````(`````````2`(`````
M``!(`@```````!@#````````!0`````````(``````````0`````````/0``
M``L````"`````````&`%````````8`4```````!("0````````8````!````
M"``````````8`````````$4````#`````@````````"H#@```````*@.````
M````K00```````````````````$```````````````````!-````!`````(`
M````````6!,```````!8$P```````&@!````````!0`````````(````````
M`!@`````````5P````0```!"`````````,`4````````P!0```````"(!0``
M``````4````6````"``````````8`````````&$````!````!@````````!0
M&@```````%`:````````#@```````````````````!``````````````````
M``!<`````0````8`````````8!H```````!@&@```````,`#````````````
M```````0`````````!``````````9P````$````&`````````"`>````````
M(!X````````@````````````````````"``````````(`````````'`````!
M````!@````````!`'@```````$`>````````$S@``````````````````!``
M``````````````````!V`````0````8`````````8%8```````!@5@``````
M``X````````````````````0````````````````````?`````$````"````
M`````'!6````````<%8```````!J0```````````````````"```````````
M`````````(0````!`````@````````#<E@```````-R6````````%`$`````
M``````````````0```````````````````"2`````0````(`````````\)<`
M``````#PEP```````(P&```````````````````(````````````````````
MG`````$````#`````````+BM(```````N*T````````0````````````````
M````"````````````````````*,````!`````P````````#(K2```````,BM
M````````$`````````````````````@```````````````````"J`````0``
M``,`````````V*T@``````#8K0````````@````````````````````(````
M````````````````KP````8````#`````````."M(```````X*T```````#`
M`0````````8`````````"``````````0`````````&L````!`````P``````
M``"@KR```````*"O````````8`````````````````````@`````````"```
M``````"X`````0````,``````````+`@````````L````````/`!````````
M```````````(``````````@`````````P0````$````#`````````/"Q(```
M````\+$```````!P````````````````````"````````````````````,<`
M```(`````P````````"`LB```````&"R````````2```````````````````
M`$````````````````````#,`````0```#````````````````````!@L@``
M`````#L````````````````````!``````````$`````````'P````$`````
M````````````````````F[(```````!5`0```````````````````0``````
M`````````````-4````!`````````````````````````/"S````````CP``
M``````````````````0````````````````````!`````P``````````````
M``````````!_M````````-\````````````````````!````````````````
#````
